# scisbi - Scientific Machine Learning package for Simulation Based Inference

A personal project with multiple aims:

- Creating final project for my PhD course TTSSE (Techniques and Technologies for Scientific Software Engeneering) in Uppsala University
- Rewriting codes for existing simulation based inference methods and frameworks around them for gaining knowledge about current SOTA methods for further research
- Gaining experience in creating, developing and at least shortly maintaining OSS


# Notes

## Documentation

[scisbi.readthedocs.io](https://scisbi.readthedocs.io)

Other better maintained python packages might be more suitable for personal, research or applied uage, such as

- [sbi](https://github.com/sbi-dev/sbi)
- [bayesflow](https://github.com/bayesflow-org/bayesflow)
- [sciope](https://github.com/StochSS/sciope)
- [sbijax](https://github.com/dirmeier/sbijax)

*This project is using the following packages:*
